# coding: utf-8

"""
    ORCID Member

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: Latest
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from orcid_api_v3.models.created_date_v30 import CreatedDateV30  # noqa: F401,E501
from orcid_api_v3.models.credit_name_v30 import CreditNameV30  # noqa: F401,E501
from orcid_api_v3.models.family_name_v30 import FamilyNameV30  # noqa: F401,E501
from orcid_api_v3.models.given_names_v30 import GivenNamesV30  # noqa: F401,E501
from orcid_api_v3.models.last_modified_date_v30 import LastModifiedDateV30  # noqa: F401,E501
from orcid_api_v3.models.source_v30 import SourceV30  # noqa: F401,E501


class NameV30(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_date': 'CreatedDateV30',
        'last_modified_date': 'LastModifiedDateV30',
        'given_names': 'GivenNamesV30',
        'family_name': 'FamilyNameV30',
        'credit_name': 'CreditNameV30',
        'source': 'SourceV30',
        'visibility': 'str',
        'path': 'str'
    }

    attribute_map = {
        'created_date': 'created-date',
        'last_modified_date': 'last-modified-date',
        'given_names': 'given-names',
        'family_name': 'family-name',
        'credit_name': 'credit-name',
        'source': 'source',
        'visibility': 'visibility',
        'path': 'path'
    }

    def __init__(self, created_date=None, last_modified_date=None, given_names=None, family_name=None, credit_name=None, source=None, visibility=None, path=None):  # noqa: E501
        """NameV30 - a model defined in Swagger"""  # noqa: E501
        self._created_date = None
        self._last_modified_date = None
        self._given_names = None
        self._family_name = None
        self._credit_name = None
        self._source = None
        self._visibility = None
        self._path = None
        self.discriminator = None
        if created_date is not None:
            self.created_date = created_date
        if last_modified_date is not None:
            self.last_modified_date = last_modified_date
        if given_names is not None:
            self.given_names = given_names
        if family_name is not None:
            self.family_name = family_name
        if credit_name is not None:
            self.credit_name = credit_name
        if source is not None:
            self.source = source
        if visibility is not None:
            self.visibility = visibility
        if path is not None:
            self.path = path

    @property
    def created_date(self):
        """Gets the created_date of this NameV30.  # noqa: E501


        :return: The created_date of this NameV30.  # noqa: E501
        :rtype: CreatedDateV30
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this NameV30.


        :param created_date: The created_date of this NameV30.  # noqa: E501
        :type: CreatedDateV30
        """

        self._created_date = created_date

    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this NameV30.  # noqa: E501


        :return: The last_modified_date of this NameV30.  # noqa: E501
        :rtype: LastModifiedDateV30
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this NameV30.


        :param last_modified_date: The last_modified_date of this NameV30.  # noqa: E501
        :type: LastModifiedDateV30
        """

        self._last_modified_date = last_modified_date

    @property
    def given_names(self):
        """Gets the given_names of this NameV30.  # noqa: E501


        :return: The given_names of this NameV30.  # noqa: E501
        :rtype: GivenNamesV30
        """
        return self._given_names

    @given_names.setter
    def given_names(self, given_names):
        """Sets the given_names of this NameV30.


        :param given_names: The given_names of this NameV30.  # noqa: E501
        :type: GivenNamesV30
        """

        self._given_names = given_names

    @property
    def family_name(self):
        """Gets the family_name of this NameV30.  # noqa: E501


        :return: The family_name of this NameV30.  # noqa: E501
        :rtype: FamilyNameV30
        """
        return self._family_name

    @family_name.setter
    def family_name(self, family_name):
        """Sets the family_name of this NameV30.


        :param family_name: The family_name of this NameV30.  # noqa: E501
        :type: FamilyNameV30
        """

        self._family_name = family_name

    @property
    def credit_name(self):
        """Gets the credit_name of this NameV30.  # noqa: E501


        :return: The credit_name of this NameV30.  # noqa: E501
        :rtype: CreditNameV30
        """
        return self._credit_name

    @credit_name.setter
    def credit_name(self, credit_name):
        """Sets the credit_name of this NameV30.


        :param credit_name: The credit_name of this NameV30.  # noqa: E501
        :type: CreditNameV30
        """

        self._credit_name = credit_name

    @property
    def source(self):
        """Gets the source of this NameV30.  # noqa: E501


        :return: The source of this NameV30.  # noqa: E501
        :rtype: SourceV30
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this NameV30.


        :param source: The source of this NameV30.  # noqa: E501
        :type: SourceV30
        """

        self._source = source

    @property
    def visibility(self):
        """Gets the visibility of this NameV30.  # noqa: E501


        :return: The visibility of this NameV30.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this NameV30.


        :param visibility: The visibility of this NameV30.  # noqa: E501
        :type: str
        """
        allowed_values = ["LIMITED", "REGISTERED_ONLY", "PUBLIC", "PRIVATE"]  # noqa: E501
        if visibility not in allowed_values:
            raise ValueError(
                "Invalid value for `visibility` ({0}), must be one of {1}"  # noqa: E501
                .format(visibility, allowed_values)
            )

        self._visibility = visibility

    @property
    def path(self):
        """Gets the path of this NameV30.  # noqa: E501


        :return: The path of this NameV30.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this NameV30.


        :param path: The path of this NameV30.  # noqa: E501
        :type: str
        """

        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NameV30, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NameV30):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
